# PiKVM V4 Mini & Plus

<img src="overview.jpg" width="400" />

* [PiKVM V4 Mini Datasheet PDF](v4mini_datasheet.pdf)
* [PiKVM V4 Plus Datasheet PDF](v4plus_datasheet.pdf)


## Installation requirements

* PiKVM V4 Mini or Plus box kit.
* Any reliable HDMI cable.


## Basic setup

1. Unpack the box and connect the PiKVM according to diagram:

    | Back side | Front side |
    |-----------|------------|
    | <img src="plus_back.jpg" width="300" /> | <img src="plus_front.jpg" width="300" /> |

    * **HDMI input** (the **bottom right** on the **back** side) and **OTG** port (USB emulation) should be connected to the computer. Optionally, the **[ATX port](atx_board.md)** can be connected to control the power. There should be no USB hub between PiKVM and the computer, as some UEFI/BIOS cannot detect them at the boot stage.

    * Connect **Ethernet** (**bottom right** on the **front** size) to the network using the cable from the kit. The kit includes two Ethernet cables of different colors: one for the network, the second for ATX. Use whichever one you like best.

    * Use the power supply and turn on PiKVM. The Mini comes with USB-C 5V power supply, and Plus with Barrel 12V. Use the appropriate connector on the **front** side. Please note that Plus can also work from 5V, in this case, do not connect a 12V power supply and don't create a significant power load on USB (external flash sticks, cameras, and so on).

    !!! warning "Do not block the ventilation holes on the sides of the device. This is especially true for the V4 Plus, which has active cooling."

2. Wait until PiKVM starts and shows a greeting on the built-in display. Do not turn off the device until it's fully booted for the first time.

3. **Carefully read [the "First steps" guide](first_steps.md){target=_blank}** - how to find a device on the network, how to log in there, change passwords, and so on. **Follow the steps described there and come back to this page**.

4. ??? note "Using Fahrenheit instead of Celsius on the OLED"
    ```
    # mkdir -p /etc/systemd/system/kvmd-oled.service.d
    ```
    Create file `touch or nano /etc/systemd/system/kvmd-oled.service.d/override.conf`:
    ```ini
    [Service]
    ExecStart=
    ExecStart=/usr/bin/kvmd-oled --clear-on-exit --fahrenheit
    ```
    And run `systemctl restart kvmd-oled`. In some cases, if you still do not see Fahrenheit being displayed, reboot the device.

5. **Just reminding again:**

    {!_passwd.md!}

6. **Try to manage the computer using PiKVM with the Web Interface.** Make sure that you get an image and both keyboard and mouse are working. If something doesn't work, check out our [FAQ](faq.md) (it's really useful). If nothing helped, you can get support in our [Discord chat](https://discord.gg/bpmXfz5).

7. Explore the features of PiKVM using the site's table of contents and have fun!


## 1920x1200 video mode

Both PiKVM V4 Mini and Plus devices support a resolution 1920x1200, however, for compatibility reasons, the default configuration uses 1920x1080.
To enable 1920x1200, follow [this manual](edid.md).


## ATX connection

[See here](atx_board.md).


## DIP switches

There is a pair of DIP switches on the V4 right side.

| Right side |
|------------|
| <img src="plus_right.jpg" width="450" /> |

* The left switch **[1]**. When pulled down (**ON** state), the advanced backpower protection is used.
  On the default state is **OFF** (up), "diode protection" is used.

* The right switch **[2]**. When pulled down (**ON** state), the Power Delivery chip is activated on the USB OTG port.
  The default state is **OFF** (up).


## Internal USB on V4 Plus

The V4 Plus has an internal USB port that can be used at your discretion.
It supports USB 3.0, but by default it only works with USB 2.0 devices due to energy savings.
To enable USB 3.0, it is required to flash the USB controller firmware. It's very easy:

1. Install the package `flashrom-pikvm`:
    ```
    # rw
    # pacman -Syu
    # pacman -S flashrom-pikvm
    ```
2. Flash the firmware: `usb3` for USB 3.0 support, or `default` for the default USB 2.0-only firmware, and reboot:
    ```
    # flashrom-vl805 usb3
    # reboot
    ```


## Known issues and limitations
* The actual frame rate of the image received via HDMI will depend on the network bandwidth, resolution and the load on the Raspberry Pi. This is usually **~24-28 FPS for 1080p over LAN**.
* There may be **compatibility** issues with some motherboards (such as **HP** or **DELL**) which are the same as those that exist with PiKVM V2. Not everything is perfect, but if you have already used PiKVM V2 - our new V4 will work great and please you. If there is no image from the BIOS, you can fine-tune the HDMI settings, but it is possible that the Mass Storage devices will not be available in the BIOS.
